This crate wraps the macros implemented in Polyhorn UI in a
proc-macro = true library.
Macros
- asset
- Calls
polyhorn_ui::macros::asset::asset_implwith a token stream that we obtain from the Rust compiler. - render
- Calls
polyhorn_ui::macros::render::render_implwith a token stream that we obtain from the Rust compiler. - style
- Calls
polyhorn_ui::macros::style::style_implwith a token stream that we obtain from the Rust compiler.
Attribute Macros
- test
- Calls
polyhorn_ui::macros::test::test_implwith a token stream that we obtain from the Rust compiler.